@@ -2,17 +2,17 @@
 #
 # Copyright (C) 2008-2012  Ricky Zhou, Red Hat, Inc.
 # This file is part of python-fedora
-# 
+#
 # python-fedora is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
 # version 2.1 of the License, or (at your option) any later version.
-# 
+#
 # python-fedora is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Lesser General Public
 # License along with python-fedora; if not, see <http://www.gnu.org/licenses/>
 #
@@ -31,6 +31,11 @@ import warnings
 from bunch import Bunch
 from kitchen.text.converters import to_bytes
 
+try:
+    import libravatar
+except ImportError:
+    libravatar = None
+
 try:
     from hashlib import md5
 except ImportError:
@@ -38,7 +43,7 @@ except ImportError:
 
 from fedora.client import AppError, BaseClient, FasProxyClient, \
         FedoraClientError, FedoraServiceError
-from fedora import __version__, b_
+from fedora import __version__ 
 
 ### FIXME: To merge:
 # /usr/bin/fasClient from fas
@@ -59,7 +64,7 @@ USERFIELDS = ['affiliation', 'bugzilla_email', 'certificate_serial',
         'ircnick', 'latitude', 'last_seen', 'longitude', 'password',
         'password_changed', 'passwordtoken', 'postal_address', 'privacy',
         'locale', 'ssh_key', 'status', 'status_change', 'telephone',
-        'unverified_email', 'timezone', 'username', 'security_question', 
+        'unverified_email', 'timezone', 'username', 'security_question',
         'security_answer', ]
 
 class AccountSystem(BaseClient):
@@ -87,13 +92,18 @@ class AccountSystem(BaseClient):
     .. versionchanged:: 0.3.26
         Added :meth:`~fedora.client.AccountSystem.gravatar_url` that returns
         a url to a gravatar for a user.
+    .. versionchanged:: 0.3.33
+        Renamed :meth:`~fedora.client.AccountSystem.gravatar_url` to
+        :meth:`~fedora.client.AccountSystem.avatar_url`.
     '''
     # proxy is a thread-safe connection to the fas server for verifying
     # passwords of other users
     proxy = None
 
-    # size that we allow to request from gravatar.com
-    _valid_gravatar_sizes = (32, 64, 140)
+    # size that we allow to request from remote avatar providers.
+    _valid_avatar_sizes = (32, 64, 140)
+    # URLs for remote avatar providers.
+    _valid_avatar_services = ['libravatar', 'gravatar']
 
     def __init__(self, base_url='https://admin.fedoraproject.org/accounts/',
             *args, **kwargs):
@@ -226,6 +236,14 @@ class AccountSystem(BaseClient):
                 160587: 'jamielinux@fedoraproject.org',
                 # Nikos Roussos: nikos@roussos.cc
                 144436: 'comzeradd@fedoraproject.org',
+                # Benedikt Schäfer: benedikt@schaefer-flieden.de
+                154726: 'ib54003@fedoraproject.org',
+                # Ricky Elrod: codeblock@elrod.me
+                139137: 'relrod@redhat.com',
+                # David Xie: david.scriptfan@gmail.com
+                167133: 'davidx@fedoraproject.org',
+                # Felix Schwarz: felix.schwarz@oss.schwarz.eu
+                103551: 'fschwarz@fedoraproject.org',
                 }
         # A few people have an email account that is used in owners.list but
         # have setup a bugzilla account for their primary account system email
@@ -268,7 +286,7 @@ class AccountSystem(BaseClient):
     insecure = property(_get_insecure, _set_insecure)
 
     ### Groups ###
-    
+
     def create_group(self, name, display_name, owner, group_type,
                      invite_only=0, needs_sponsor=0, user_can_remove=1,
                      prerequisite='', joinmsg='', apply_rules='None'):
@@ -311,7 +329,7 @@ class AccountSystem(BaseClient):
                                     req_params=req_params,
                                     auth=True)
         return request
-        
+
 
     def group_by_id(self, group_id):
         '''Returns a group object based on its id'''
@@ -331,8 +349,8 @@ class AccountSystem(BaseClient):
         if request['success']:
             return request['group']
         else:
-            raise AppError(message=b_('FAS server unable to retrieve group'
-                ' %(group)s') % {'group': to_bytes(groupname)},
+            raise AppError(message='FAS server unable to retrieve group'
+                ' %(group)s' % {'group': to_bytes(groupname)},
                 name='FASError')
 
     def group_members(self, groupname):
@@ -406,58 +424,117 @@ class AccountSystem(BaseClient):
         else:
             return dict()
 
-    def gravatar_url(self, username, size=64,
-                     default=None, lookup_email=True):
-        ''' Returns a URL to a gravatar for a given username.
+    def avatar_url(self, username, size=64,
+                   default=None, lookup_email=True,
+                   service=None):
+        ''' Returns a URL to an avatar for a given username.
 
-        :arg username: FAS username to construct a gravatar url for
-        :kwarg size: size of the gravatar.  Allowed sizes are 32, 64, 140.
+        Avatars are drawn from third party services.
+
+        :arg username: FAS username to construct a avatar url for
+        :kwarg size: size of the avatar.  Allowed sizes are 32, 64, 140.
             Default: 64
-        :kwarg default: If gravatar does not have a gravatar image for the
+        :kwarg default: If the service does not have a avatar image for the
             email address, this url is returned instead.  Default:
             the fedora logo at the specified size.
         :kwarg lookup_email:  If true, use the email from FAS, otherwise just
-            append @fedoraproject.org to the username.  Not that this will be
-            much slower if lookup_email is set to True since we'd have to make a
-            query against FAS itself.
-        :raises ValueError: if the size parameter is not allowed
+            append @fedoraproject.org to the username.  Note that this will be
+            much slower if lookup_email is set to True since we'd have to make
+            a query against FAS itself.
+        :kwarg service: One of 'libravatar' or 'gravatar'.
+            Default: 'libravatar'.
+        :raises ValueError: if the size parameter is not allowed or if the
+            service is not one of 'libravatar' or 'gravatar'
         :rtype: :obj:`str`
-        :returns: url of a gravatar for the user
+        :returns: url of a avatar for the user
 
-        If that user has no gravatar entry, instruct gravatar.com to redirect
-        us to the Fedora logo.
+        If that user has no avatar entry, instruct the remote service to
+        redirect us to the Fedora logo.
 
         If that user has no email attribute, then make a fake request to
-        gravatar.
+        the third party service.
 
         .. versionadded:: 0.3.26
         .. versionchanged: 0.3.30
-            Add lookup_email parameter to control whether we generate gravatar
+            Add lookup_email parameter to control whether we generate avatar
             urls with the email in fas or username@fedoraproject.org
+        .. versionchanged: 0.3.33
+            Renamed from `gravatar_url` to `avatar_url`
         '''
-        if size not in self._valid_gravatar_sizes:
-            raise ValueError(b_('Size %(size)i disallowed.  Must be in'
-                ' %(valid_sizes)r') % { 'size': size,
-                    'valid_sizes': self._valid_gravatar_sizes})
+
+        if size not in self._valid_avatar_sizes:
+            raise ValueError('Size %(size)i disallowed.  Must be in'
+                ' %(valid_sizes)r' % { 'size': size,
+                    'valid_sizes': self._valid_avatar_sizes})
+
+        # If our caller explicitly requested libravatar but they don't have
+        # it installed, then we need to raise a nice error and let them know.
+        if service == 'libravatar' and not libravatar:
+            raise ValueError("Install python-pylibravatar if you want to "
+                             "use libravatar as an avatar provider.")
+
+        # If our caller didn't specify a service, let's pick a one for them.
+        # If they have pylibravatar installed, then by all means let freedom
+        # ring!  Otherwise, we'll use gravatar.com if we have to.
+        if not service:
+            if libravatar:
+                service = 'libravatar'
+            else:
+                service = 'gravatar'
+
+        # Just double check to make sure they didn't pass us a bogus service.
+        if service not in self._valid_avatar_services:
+            raise ValueError('Service %(service)r disallowed.  Must be in'
+                ' %(valid_services)r' % { 'service': service,
+                    'valid_services': self._valid_avatar_services})
 
         if not default:
             default = "http://fedoraproject.org/static/images/" + \
                     "fedora_infinity_%ix%i.png" % (size, size)
 
-        query_string = urllib.urlencode({
-            's': size,
-            'd': default,
-        })
-
         if lookup_email:
             person = self.person_by_username(username)
             email = person.get('email', 'no_email')
         else:
             email = "%s@fedoraproject.org" % username
 
-        hash = md5(email).hexdigest()
+        if service == 'libravatar':
+            return libravatar.libravatar_url(
+                email=email,
+                size=size,
+                default=default,
+            )
+        else:
+            query_string = urllib.urlencode({
+                's': size,
+                'd': default,
+            })
 
-        return "http://www.gravatar.com/avatar/%s?%s" % (hash, query_string)
+            hash = md5(email).hexdigest()
+
+            return "http://www.gravatar.com/avatar/%s?%s" % (hash, query_string)
+
+    def gravatar_url(self, *args, **kwargs):
+        """ *Deprecated* - Use avatar_url.
+
+         .. versionadded:: 0.3.26
+         .. versionchanged: 0.3.30
+            Add lookup_email parameter to control whether we generate gravatar
+            urls with the email in fas or username@fedoraproject.org
+         .. versionchanged: 0.3.33
+            Deprecated in favor of `avatar_url`.
+        """
+
+        warnings.warn("gravatar_url is deprecated and will be removed in"
+            " a future version.  Please port your code to use avatar_url(...,"
+            " service='libravatar', ...)  instead",
+            DeprecationWarning, stacklevel=2)
+
+        if 'service' in kwargs:
+            raise TypeError("'service' is an invalid keyword argument for"
+                            " this function.  Use avatar_url() instead)")
+
+        return self.avatar_url(*args, service='gravatar', **kwargs)
 
     def user_id(self):
         '''Returns a dict relating user IDs to usernames'''
@@ -527,15 +604,15 @@ class AccountSystem(BaseClient):
         '''
         # Make sure we have a valid key value
         if key not in ('id', 'username', 'email'):
-            raise KeyError(b_('key must be one of "id", "username", or'
-                ' "email"'))
+            raise KeyError('key must be one of "id", "username", or'
+                ' "email"')
 
         if fields:
             fields = list(fields)
             for field in fields:
                 if field not in USERFIELDS:
-                    raise KeyError(b_('%(field)s is not a valid field to'
-                        ' filter') % {'field': to_bytes(field)})
+                    raise KeyError('%(field)s is not a valid field to'
+                        ' filter' % {'field': to_bytes(field)})
         else:
             fields = USERFIELDS
 
@@ -587,10 +664,10 @@ class AccountSystem(BaseClient):
         .. versionchanged:: 0.3.21
             Return a Bunch instead of a DictContainer
         '''
-        warnings.warn(b_("people_by_id() is deprecated and will be removed in"
+        warnings.warn("people_by_id() is deprecated and will be removed in"
             " 0.4.  Please port your code to use people_by_key(key='id',"
             " fields=['human_name', 'email', 'username', 'bugzilla_email'])"
-            " instead"), DeprecationWarning, stacklevel=2)
+            " instead", DeprecationWarning, stacklevel=2)
 
         request = self.send_request('/json/user_id', auth=True)
         user_to_id = {}
@@ -769,8 +846,8 @@ class AccountSystem(BaseClient):
             if request['success']:
                 return request['data']
             else:
-                raise AppError(message=b_('FAS server unable to retrieve'
-                    ' group members'), name='FASError')
+                raise AppError(message='FAS server unable to retrieve'
+                    ' group members', name='FASError')
         except FedoraServiceError:
             raise
 
@@ -791,8 +868,8 @@ class AccountSystem(BaseClient):
             if request['success']:
                 return request['data']
             else:
-                raise AppError(message=b_('FAS server unable to retrieve user'
-                    ' information'), name='FASError')
+                raise AppError(message='FAS server unable to retrieve user'
+                    ' information', name='FASError')
         except FedoraServiceError:
             raise
 
