@@ -31,10 +31,8 @@ import warnings
 
 from kitchen.iterutils import isiterable as _isiterable
 
-from fedora import b_
-
-warnings.warn(b_('fedora.iterutils is deprecated.  Use kitchen.iterutils'
-    ' instead'), DeprecationWarning, stacklevel=2)
+warnings.warn('fedora.iterutils is deprecated.  Use kitchen.iterutils'
+    ' instead', DeprecationWarning, stacklevel=2)
 
 def isiterable(obj, include_string=True):
     '''*Deprecated* Use kitchen.iterutils.isiterable instead.
@@ -51,8 +49,8 @@ def isiterable(obj, include_string=True):
         cause this function to return False.
     :returns: True if `obj` is iterable, otherwise False.
     '''
-    warnings.warn(b_('fedora.iterutils.isiterable is deprecated, use'
-        ' kitchen.iterutils.isiterable instead'), DeprecationWarning,
+    warnings.warn('fedora.iterutils.isiterable is deprecated, use'
+        ' kitchen.iterutils.isiterable instead', DeprecationWarning,
         stacklevel=2)
     return _isiterable(obj, include_string)
 
