@@ -28,9 +28,7 @@ Functions to manipulate unicode and byte strings
 import warnings
 from kitchen.text.converters import to_unicode, to_bytes
 
-from fedora import b_
-
-warnings.warn(b_('fedora.textutils is deprecated.  Use'
-    ' kitchen.text.converters instead'), DeprecationWarning, stacklevel=2)
+warnings.warn('fedora.textutils is deprecated.  Use'
+    ' kitchen.text.converters instead', DeprecationWarning, stacklevel=2)
 
 __all__ = ('to_unicode', 'to_bytes')
