@@ -3,4 +3,4 @@ Functions and classes to help build a Fedora Service.
 '''
 
 __all__ = ('client', 'json', 'tg1utils', 'tg2utils', 'widgets',
-        'identity', 'visit')
+        'identity', 'utils', 'visit')
