@@ -33,7 +33,7 @@ from kitchen.text.converters import to_bytes
 
 from fedora.client import FasProxyClient
 
-from fedora import b_, __version__
+from fedora import __version__
 
 import logging
 log = logging.getLogger("turbogears.identity.jsonfasvisit")
@@ -133,7 +133,7 @@ class JsonFasVisitManager(BaseVisitManager):
         self.log.debug('JsonFasVisitManager.update_queued_visits: %s' % len(queue))
         # Hit any URL in fas with each visit_key to update the sessions
         for visit_key in queue:
-            self.log.info(b_('updating visit (%s)'), to_bytes(visit_key))
+            self.log.info('updating visit (%s)', to_bytes(visit_key))
             try:
                 self.fas.refresh_session(visit_key)
             except Exception:
